import { TextFieldProps } from '@mui/material/TextField';
import { ReactNode } from 'react';
export type UnitType = 'Length' | 'Weight' | 'Volume' | 'ForcePerLength' | 'CustomUnit';
export interface Unit<T> {
    /**
     * The unit type
     */
    type: T;
    /**
     * the maximum value of the unit
     */
    maxValue?: number;
    /**
     * the minimum value of the unit
     */
    minValue?: number;
    /**
     * This is the default unit
     */
    isDefault: boolean;
    /**
     * the display name of the unit
     */
    displayName: string;
    /**
     * Shortened version of the units to display in the closed unit picker
     */
    shortUnits?: string;
    /**
     * the alternative display name of the unit
     */
    secondaryDisplayStrings?: ReadonlyArray<string>;
    placeholder?: string;
    /**
     * the function to format the value
     * if not provided, the value will be formatted as a number.
     * @param value
     */
    valueFormatter?: (value: string) => string | number;
}
export interface UnitFormatterValue {
    value: number | string;
    unit: string;
}
type CommonUnitFormatterProps = Omit<TextFieldProps, 'onChange' | 'value' | 'onBlur'> & {
    /**
     * @description The unit type to be displayed in the input the options are: 'Length' | 'Weight' | 'Volume' | 'ForcePerLength' | 'CustomUnit'
     */
    unitType: UnitType;
    /**
     * The initial value of the unit formatter
     */
    initialValue?: UnitFormatterValue;
    /**
     * The placement of the unit
     * @default 'start'
     */
    unitPlacement?: 'start' | 'end' | 'input';
    /**
     * The units to be displayed in the input
     *
     * interface Unit<T> {
     *    type: T;
     *    minValue?: number;
     *    maxValue?: number;
     *    isDefault: boolean;
     *    displayName: string;
     *    secondaryDisplayStrings?: string[];
     *    placeholder?: string;
     *    valueFormatter?: (value: string) => string | number;
     *  }
     * @default []
     */
    units?: ReadonlyArray<Unit<any>>;
    /**
     * Whether to show the number stepper
     * @default false
     */
    showIncrementDecrementButtons?: boolean;
    /**
     * Handle value change
     * @param {UnitFormatterValue} value
     */
    onChange?: (value: UnitFormatterValue) => void;
    /**
     * @description The unit to be displayed at the start of the input.
     */
    startAdornment?: ReactNode;
    /**
     * @description The unit to be displayed at the end of the input.
     */
    endAdornment?: ReactNode;
    /**
     * Whether to disable user inputs (for text field and dropdown)
     * @default false
     */
    readOnly?: boolean;
};
export type InsideUnitFormatterProps = CommonUnitFormatterProps & {
    unitType: Exclude<UnitType, 'CustomUnit'>;
};
export type CustomizeUnitFormatterProps = CommonUnitFormatterProps & Required<{
    unitType: 'CustomUnit';
    units: ReadonlyArray<Unit<any>>;
}>;
export type SimpleUnitFormatterProps = Omit<InsideUnitFormatterProps, 'ref'> | Omit<CustomizeUnitFormatterProps, 'ref'>;
export type SimpleUnitFormatterRef = {
    reset: (initialValue?: UnitFormatterValue) => void;
};
export type UnitFormatterProps = Omit<SimpleUnitFormatterProps, 'initialValue'> & {
    value: SimpleUnitFormatterProps['initialValue'];
    ref?: CommonUnitFormatterProps['ref'];
    /**
     * @description The function to handle the unit change
     * @param unit
     */
    onUnitSelectChange?: (unit: string) => void;
    /**
     * @description The function to handle the step increment
     */
    onStepIncrement?: () => void;
    /**
     * @description The function to handle the step decrement
     */
    onStepDecrement?: () => void;
    onBlur?: (value: UnitFormatterValue) => void;
    /**
     * @description The step value of the number stepper, recommended it is an integer to avoid the precision issue.
     * @default 1
     */
    stepperIncrement?: number;
};
export {};
